Chancellor's Office Portal Home
Author: Home Portal -- California Community Colleges Chancellor's Office
Description: Welcome to the home portal for the California Community College's Chancellor's Office web presence. Here you will find access to the 3 main websites of our agency: CaliforniaCommunityColleges.cccco.edu -- Primary public website Extranet.cccco.edu -- System website Datamart.cccco.edu -- Data analysis and reporting website
Keywords: portal, California Community Colleges, Chancellor's Office,DotNetNuke,DNN

Skip to content
Sitemap

# Welcome to the California Community Colleges Chancellor's Office

The California Community Colleges is the largest system of higher education in the nation, with 2.1 million students attending 112 colleges. Our colleges provide students with the knowledge and background necessary to compete in today’s economy. With a wide range of educational offerings, the colleges provide workforce training, basic courses in English and math, certificate and degree programs and preparation for transfer to four-year institutions.

# Our Mission

The mission of the California Community Colleges Board of Governors and the Chancellor's Office is to empower the community colleges through leadership, advocacy and support.

| ## Discover California's Community Colleges

Want to learn more about California Community Colleges? Here you will find information, tools and stories about our education system and what's going on throughout the sytem.

Tools for Students Programs to Watch Business Partnerships Chancellor's Office Policy in Action Meet the Chancellor Newsroom

| ## Student Success Initiative

The Student Success Task Force recommended 22 specific policy changes to improve educational achievement in the California Community Colleges.

Student Success Initiative For Students Reports Resources Goals & Accountability Video Gallery Timeline News

| ## Veterans Summit IV
The California Community Colleges Chancellor’s Office, Faculty Association for California Community Colleges and the Foundation for California Community Colleges are partnering to host the California Community Colleges Veterans Summit IV Dec. 4-5, 2014 at the San Jose Marriott Hotel. The summit is designed to share information and best practices for faculty, administrators and staff who work with student veterans on our campuses. For more information, please visit, www.veteranssummit.org

| ## Chancellor's Office System Operations

The Chancellor’s Office has nine divisions and each is led by a vice chancellor, performing vital tasks to keep the Chancellor’s Office running smoothly.

Student Services Academic Affairs Governmental Relations Division | Technology & Research Workforce & Economics Division
Finance & Facilities | Legal
Institutional Effectiveness | Campus Safety

| ## Research & Analysis Datamart

Datamart answers the questions posed by administrators, educators, parents, students, state leadership, and professional organizations by providing information on students, courses, student services, outcomes and faculty and staff.

Demographics Courses Characteristics Student Services data Student Outcomes Faculty & Staff.

| ## Reports & Resources

The California Community Colleges Chancellor's Office provides various reports throughout the year to the Governor's Office and legislature. These reports provide information on various key functions within the system.
To read the current and archived reports, visit our Reports & Resources section.

Alphabetic listing of community colleges
Hot Topics Video Blog
"New Sidekick Website
ToolsThatInspire.com"

## Connect with us: